#include <R.h>
#include <Rinternals.h>
#include <stdlib.h> // for NULL
#include <R_ext/Rdynload.h>

/* FIXME: 
   Check these declarations against the C/Fortran source code.
*/

/* .Call calls */
/*extern SEXP robustRegression(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 * Note SA: commented out because of "type of 'robustRegression' not not match original declaration' warning
 */
extern SEXP robustRegression(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);

static const R_CallMethodDef CallEntries[] = {
    {"robustRegression", (DL_FUNC) &robustRegression, 8},
    {NULL, NULL, 0}
};

void R_init_robfilter(DllInfo *dll)
{
    R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
    R_useDynamicSymbols(dll, FALSE);
}
